@@ -6,13 +6,14 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
+use 5.012;
 use utf8;
 use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package XML::Ant::BuildFile::Target;
 
 BEGIN {
-    $XML::Ant::BuildFile::Target::VERSION = '0.205';
+    $XML::Ant::BuildFile::Target::VERSION = '0.206';
 }
 
 # ABSTRACT: target node within an Ant build file
@@ -24,8 +25,8 @@ use MooseX::Types::Moose qw(ArrayRef Str);
 use Regexp::DefaultFlags;
 ## no critic (RequireDotMatchAnything, RequireExtendedFormatting)
 ## no critic (RequireLineBoundaryMatching)
-use XML::Ant::BuildFile::Task::Java;
 use namespace::autoclean;
+extends 'XML::Ant::BuildFile::TaskContainer';
 with 'XML::Ant::BuildFile::Role::InProject';
 
 {
@@ -53,24 +54,6 @@ sub _build_dependencies {    ## no critic (ProhibitUnusedPrivateSubroutines)
         $self->_depends ];
 }
 
-has _tasks => (
-    traits      => [qw(XPathObjectList Array)],
-    xpath_query => './/java',
-    isa_map     => { java => 'XML::Ant::BuildFile::Task::Java' },
-    handles     => {
-        all_tasks    => 'elements',
-        task         => 'get',
-        filter_tasks => 'grep',
-        num_tasks    => 'count',
-    },
-);
-
-sub tasks {
-    my ( $self, @names ) = @ARG;
-    return $self->filter_tasks( sub { $ARG->task_name ~~ @names } );
-}
-
-__PACKAGE__->meta->make_immutable();
 1;
 
 =pod
@@ -85,7 +68,7 @@ XML::Ant::BuildFile::Target - target node within an Ant build file
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 SYNOPSIS
 
@@ -113,28 +96,6 @@ If the target has any dependencies, this will return them as an array reference
 of L<XML::Ant::BuildFile::Target|XML::Ant::BuildFile::Target>
 objects.
 
-=head1 METHODS
-
-=head2 all_tasks
-
-Returns an array of task objects contained in this target.
-
-=head2 task
-
-Given an index number returns that task from the target.
-
-=head2 filter_tasks
-
-Returns all task objects for which the given code reference returns C<true>.
-
-=head2 num_tasks
-
-Returns a count of the number of tasks in this target.
-
-=head2 tasks
-
-Given one or more task names, returns a list of task objects.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
