@@ -6,13 +6,14 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
+use 5.012;
 use utf8;
 use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package XML::Ant::BuildFile::Task;
 
 BEGIN {
-    $XML::Ant::BuildFile::Task::VERSION = '0.205';
+    $XML::Ant::BuildFile::Task::VERSION = '0.206';
 }
 
 # ABSTRACT: Role for Ant build file tasks
@@ -25,10 +26,10 @@ use MooseX::Types::Moose 'Str';
 use namespace::autoclean;
 with 'XML::Ant::BuildFile::Role::InProject';
 
-has task_name => ( ro,
+has task_name => ( ro, lazy,
     isa      => Str,
     init_arg => undef,
-    default  => sub { $ARG->node->nodeName },
+    default  => sub { $ARG[0]->node->nodeName },
 );
 
 1;
@@ -45,7 +46,7 @@ XML::Ant::BuildFile::Task - Role for Ant build file tasks
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 SYNOPSIS
 
